package com.example.fieldagent.ui.addsite

import android.Manifest
import android.app.Dialog
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.os.Environment
import android.util.Log
import android.util.Patterns
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.Window
import android.widget.ArrayAdapter
import android.widget.Toast
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.PickVisualMediaRequest
import androidx.activity.result.contract.ActivityResultContracts
import androidx.core.content.FileProvider
import androidx.fragment.app.viewModels
import androidx.lifecycle.Observer
import androidx.navigation.fragment.findNavController
import com.bumptech.glide.Glide
import com.consultantapp.data.network.responseUtil.Status
import com.example.fieldagent.R
import com.example.fieldagent.data.models.responses.UserData
import com.example.fieldagent.data.network.ApisRespHandler
import com.example.fieldagent.databinding.FragmentAddSiteBinding
import com.example.fieldagent.databinding.FragmentHomeBinding
import com.example.fieldagent.databinding.SelectPhotoBinding
import com.example.fieldagent.ui.homescreen.HomeViewModel
import com.example.fieldagent.ui.homescreen.adapter.HomeAdapter
import com.example.fieldagent.utils.PER_PAGE_LOAD
import com.example.fieldagent.utils.PrefsManager
import com.example.fieldagent.utils.dialogs.ProgressDialog
import com.example.fieldagent.utils.getRequestBody
import com.example.fieldagent.utils.gone
import com.example.fieldagent.utils.hideShowView
import com.example.fieldagent.utils.isConnectedToInternet
import com.example.fieldagent.utils.showSnackBar
import com.example.fieldagent.utils.visible
import dagger.hilt.android.AndroidEntryPoint
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.RequestBody
import okhttp3.RequestBody.Companion.asRequestBody
import java.io.File
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale
import javax.inject.Inject


@AndroidEntryPoint
class AddSiteFragment : Fragment() {

    private var _binding: FragmentAddSiteBinding? = null

    private val binding get() = _binding!!

    private  val viewModel: AddSiteViewModel by viewModels()

    @Inject
    lateinit var prefsManager: PrefsManager

    private lateinit var progressDialog: ProgressDialog

    private var image:String="";
    private var selectWomenPrayerArea:String=""
    private var selectRestroom:String=""

    private lateinit var cameraLauncher: ActivityResultLauncher<Uri>
    private lateinit var galleryLauncher: ActivityResultLauncher<String>
    private lateinit var permissionLauncher: ActivityResultLauncher<Array<String>>
    private var imageUri: Uri? = null
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentAddSiteBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


        initialize()
        listener()
        bindObservers()



    }

    private fun initialize() {

        selectWomenPrayerArea=getString(R.string.yes)
        selectRestroom=getString(R.string.ok_condition)
        val options = resources.getStringArray(R.array.availability).toList()
        val adapter = ArrayAdapter(requireActivity(), R.layout.dropdown_item, options)

        binding.autoCompleteBuilding.setAdapter(adapter)

        binding.autoCompleteBuilding.setOnClickListener {

            binding.autoCompleteBuilding.showDropDown()
        }

        binding.autoCompleteBuilding.setOnItemClickListener { parent, view, position, id ->
            val selectedItem = parent.getItemAtPosition(position) as String
            Log.d("SELECTED_ITEM", "User selected: $selectedItem")
            selectWomenPrayerArea=selectedItem;
        }


        val options2 = resources.getStringArray(R.array.condition).toList()
        val adapter2 = ArrayAdapter(requireActivity(), R.layout.dropdown_item, options2)

        binding.autoCompleteTextView.setAdapter(adapter2)

        binding.autoCompleteTextView.setOnClickListener {

            binding.autoCompleteTextView.showDropDown()
        }

        binding.autoCompleteBuilding.setOnItemClickListener { parent, view, position, id ->
            val selectedItem = parent.getItemAtPosition(position) as String
            Log.d("SELECTED_ITEM", "User selected: $selectedItem")
            selectRestroom=selectedItem;
        }

    }

    private fun listener(){





        binding.ivLeft.setOnClickListener {

            findNavController().popBackStack()
        }


        binding.btnAdd.setOnClickListener {


            when{
                binding.etName.text.toString().isEmpty() -> {
                    binding.etName.showSnackBar(getString(R.string.please_enter_your_name))
                }

                binding.etLocation.text.toString().isEmpty() -> {
                    binding.etLocation.showSnackBar(getString(R.string.please_enter_your_location))
                }

                binding.etSupervisorContact.text.toString().isEmpty() -> {
                    binding.etSupervisorContact.showSnackBar(getString(R.string.please_enter_supervisor_contact_number))
                }

                binding.etSupervisorAuthority.text.toString().isEmpty() -> {
                    binding.etSupervisorAuthority.showSnackBar(getString(R.string.please_enter_supervisor_authority_mosque))
                }

                binding.etBuildingCondition.text.toString().isEmpty() -> {
                    binding.etBuildingCondition.showSnackBar(getString(R.string.please_enter_building_condition))
                }

                binding.etMosqueArea.text.toString().isEmpty() -> {
                    binding.etMosqueArea.showSnackBar(getString(R.string.please_enter_mosque_area))
                }
                binding.etApproximateNumber.text.toString().isEmpty() -> {
                    binding.etApproximateNumber.showSnackBar(getString(R.string.please_enter_approximate_number_worshippers))
                }
                image.isEmpty() -> {
                    binding.rvImage.showSnackBar(getString(R.string.please_select_image))
                }
                isConnectedToInternet(requireActivity(), true) -> {
                    val hashMap = HashMap<String, RequestBody>()
                    hashMap["name"] = getRequestBody(binding.etName.text.toString())
                    hashMap["location"] = getRequestBody(binding.etLocation.text.toString())
                    hashMap["supervisor_name"] = getRequestBody(binding.etSupervisorAuthority.text.toString())
                    hashMap["supervisor_phone_number"] = getRequestBody(binding.etSupervisorContact.text.toString())
                    hashMap["site_condition"] = getRequestBody(binding.etBuildingCondition.text.toString())
                    hashMap["area"] = getRequestBody(binding.etMosqueArea.text.toString())
                    //hashMap["women_prayer_area"] = binding.wom.text.toString()
                    hashMap["total_capacity"] = getRequestBody(binding.etApproximateNumber.text.toString())
                    //hashMap["total_restrooms"] = binding.etPassword.text.toString()


               //     val body: RequestBody = fileToUpload?.asRequestBody("image/*".toMediaType())!!
                 //   hashMap["image\"; fileName=\"" + fileToUpload?.name] = body*/
                   // viewModel.addSites(hashMap)
                }
            }

        }


        binding.rvImage.setOnClickListener {
            showImageDialog();
        }

        cameraLauncher = registerForActivityResult(ActivityResultContracts.TakePicture()) { success ->
            if (success) {
                imageUri?.let {
                    // Handle image from camera
                    binding.rvImage.gone()
                    binding.ivSetImage.setImageURI(imageUri)
                    binding.ivCloseImage.visible()
                }
            }
        }

        galleryLauncher = registerForActivityResult(ActivityResultContracts.GetContent()) { uri ->
            uri?.let {

                binding.llUploadImage.gone()
                binding.ivSetImage.visible()
                Glide.with(this).load(imageUri).into(binding.ivSetImage)
                binding.ivCloseImage.visible()

            }
        }

        binding.ivCloseImage.setOnClickListener {

            binding.llUploadImage.visible()
            binding.ivSetImage.visible()
            Glide.with(this).load(imageUri).into(binding.ivSetImage)
            binding.ivCloseImage.visible()
        }

        // Permission launcher
        permissionLauncher = registerForActivityResult(ActivityResultContracts.RequestMultiplePermissions()) { permissions ->
            if (permissions[Manifest.permission.CAMERA] == true) {
                openCamera()
            } else {
                Toast.makeText(requireContext(), "Camera permission denied", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun bindObservers() {
        viewModel.sites.observe(requireActivity(), Observer {
            it ?: return@Observer
            when (it.status) {
                Status.SUCCESS -> {

                    findNavController().popBackStack();
                    progressDialog.setLoading(false)
                }
                Status.ERROR -> {
                    progressDialog.setLoading(false)
                    ApisRespHandler.handleError(it.error, requireActivity())
                }
                Status.LOADING -> {
                    progressDialog.setLoading(true)
                }
            }
        })
    }

    fun showImageDialog() {
        val dialog: Dialog = Dialog(requireActivity())
        val view = SelectPhotoBinding.inflate(layoutInflater)
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        dialog.setContentView(view.root)

        view.tvGallery.setOnClickListener {
            galleryLauncher.launch("image/*")
            dialog.dismiss()
        }


        view.tvCamera.setOnClickListener {
            permissionLauncher.launch(arrayOf(Manifest.permission.CAMERA))

            dialog.dismiss()
        }
        dialog.show()
    }


    private fun openCamera() {
        imageUri = FileProvider.getUriForFile(
            requireContext(),
            "${requireContext().packageName}.provider",
            createImageFile()
        )
        cameraLauncher.launch(imageUri!!)


    }

    private fun createImageFile(): File {
        val timeStamp = SimpleDateFormat("yyyyMMdd_HHmmss", Locale.getDefault()).format(Date())
        val fileName = "JPEG_${timeStamp}_"
        val storageDir = requireContext().getExternalFilesDir(Environment.DIRECTORY_PICTURES)
        return File.createTempFile(fileName, ".jpg", storageDir)
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }


}