package com.example.fieldagent.ui.addsite

import androidx.lifecycle.ViewModel
import com.example.fieldagent.data.apis.WebService
import com.example.fieldagent.data.models.responses.UserData
import com.example.fieldagent.data.network.responseUtil.ApiResponse
import com.example.fieldagent.data.network.responseUtil.ApiUtils
import com.example.fieldagent.data.network.responseUtil.Resource
import com.example.fieldagent.di.SingleLiveEvent
import dagger.hilt.android.lifecycle.HiltViewModel
import okhttp3.RequestBody
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import javax.inject.Inject


@HiltViewModel
class AddSiteViewModel  @Inject constructor(private val webService: WebService) : ViewModel() {

    val sites by lazy { SingleLiveEvent<Resource<UserData>>() }

    fun addSites(hashMap: HashMap<String, RequestBody>) {
        sites.value = Resource.loading()

        webService.createInspections(hashMap)
            .enqueue(object : Callback<UserData> {

                override fun onResponse(call: Call<UserData>,
                                        response: Response<UserData>
                ) {
                    if (response.isSuccessful) {
                        sites.value = Resource.success(response.body())

                    } else {
                        sites.value = Resource.error(
                            ApiUtils.getError(response.code(),
                                response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<UserData>, throwable: Throwable) {
                    sites.value = Resource.error(ApiUtils.failure(throwable))
                }

            })
    }


}